@@ -13,9 +13,7 @@ spec :: Spec
 spec = describe "MockT + expects integration" do
   it "allows expects inside runMockT" do
     runMockT @IO do
-      f <-
-        mock (any @String ~> True)
-          `expects` do
-            called once `with` "foo"
+      f <- mock (any @String ~> True)
+        `expects` called once `with` "foo"
       _ <- liftIO $ evaluate (f "foo")
       pure ()
