@@ -10,7 +10,6 @@
 {-# LANGUAGE UndecidableInstances #-}
 {-# OPTIONS_GHC -Wno-orphans #-}
 {-# OPTIONS_GHC -Wno-name-shadowing #-}
-{-# OPTIONS_GHC -Wno-unused-do-bind #-}
 
 module Test.MockCat.PartialMockSpec (spec) where
 
@@ -27,11 +26,8 @@ import Prelude hiding (readFile, writeFile)
 import Data.Data
 import GHC.TypeLits (KnownSymbol, symbolVal)
 import Unsafe.Coerce (unsafeCoerce)
-
 import qualified Test.MockCat.Verify as Verify
 
-
-
 ensureVerifiable ::
   ( MonadIO m
   , Verify.ResolvableMock target
@@ -45,7 +41,6 @@ ensureVerifiable target =
       [] -> Verify.verificationFailure
       _ -> pure ()
 
-
 instance UserInputGetter IO where
   getInput = getLine
   toUserInput "" = pure Nothing
@@ -55,7 +50,6 @@ instance ExplicitlyReturnMonadicValuesPartialTest IO where
   echoExplicitPartial _ = pure ()
   getByExplicitPartial s = pure (length s)
 
-
 instance (MonadIO m, FileOperation m) => FileOperation (MockT m) where
   readFile path = MockT do
     defs <- getDefinitions
@@ -128,12 +122,12 @@ _writeFile ::
   , MonadIO m
   ) =>
   params ->
-  MockT m (FilePath -> Text -> ())
+  MockT m (MockResult (Verify.ResolvableParamsOf (FilePath -> Text -> ())))
 _writeFile p = MockT $ do
   mockInstance <- unMockT $ mock (label "writeFile") p
   ensureVerifiable mockInstance
   addDefinition (Definition (Proxy :: Proxy "writeFile") mockInstance NoVerification)
-  pure mockInstance
+  pure (MockResult ())
 
 _getInput ::
   ( MockDispatch (IsMockSpec params) params (MockT m) String
@@ -141,12 +135,12 @@ _getInput ::
   , Typeable (Verify.ResolvableParamsOf String)
   ) =>
   params ->
-  MockT m String
+  MockT m (MockResult (Verify.ResolvableParamsOf String))
 _getInput value = MockT $ do
   mockInstance <- unMockT $ mock (label "getInput") value
   ensureVerifiable mockInstance
   addDefinition (Definition (Proxy :: Proxy "getInput") mockInstance NoVerification)
-  pure mockInstance
+  pure (MockResult ())
 
 _toUserInput ::
   ( MockDispatch (IsMockSpec params) params (MockT m) (String -> m (Maybe UserInput))
@@ -166,23 +160,23 @@ _getByPartial ::
   ( MockDispatch (IsMockSpec params) params (MockT IO) (String -> IO Int)
   ) =>
   params ->
-  MockT IO (String -> IO Int)
+  MockT IO (MockResult (Verify.ResolvableParamsOf (String -> IO Int)))
 _getByPartial p = MockT $ do
   mockInstance <- unMockT $ mock (label "getBy") p
   ensureVerifiable mockInstance
   addDefinition (Definition (Proxy :: Proxy "getBy") mockInstance NoVerification)
-  pure mockInstance
+  pure (MockResult ())
 
 _echoPartial ::
   ( MockDispatch (IsMockSpec params) params (MockT IO) (String -> IO ())
   ) =>
   params ->
-  MockT IO (String -> IO ())
+  MockT IO (MockResult (Verify.ResolvableParamsOf (String -> IO ())))
 _echoPartial p = MockT $ do
   mockInstance <- unMockT $ mock (label "echo") p
   ensureVerifiable mockInstance
   addDefinition (Definition (Proxy :: Proxy "echo") mockInstance NoVerification)
-  pure mockInstance
+  pure (MockResult ())
 
 findParam :: KnownSymbol sym => Proxy sym -> [Definition] -> Maybe a
 findParam pa definitions = do
@@ -215,7 +209,7 @@ _findIds ::
   , Typeable [a]
   ) =>
   p ->
-  MockT m [a]
+  MockT m (MockResult (Verify.ResolvableParamsOf [a]))
 _findIds p = MockT $ do
   mockInstance <- unMockT $ mock (label "_findIds") p
 
@@ -226,14 +220,14 @@ _findIds p = MockT $ do
         mockInstance
         NoVerification
     )
-  pure mockInstance
+  pure (MockResult ())
 
 _findById ::
   ( MockDispatch (IsMockSpec params) params (MockT m) (Int -> String)
   , MonadIO m
   ) =>
   params ->
-  MockT m (Int -> String)
+  MockT m (MockResult (Verify.ResolvableParamsOf (Int -> String)))
 _findById p = MockT $ do
   mockInstance <- unMockT $ mock (label "_findById") p
   ensureVerifiable mockInstance
@@ -243,13 +237,13 @@ _findById p = MockT $ do
         mockInstance
         NoVerification
     )
-  pure mockInstance
+  pure (MockResult ())
 
 _findByIdNI ::
   ( MockDispatch (IsMockSpec params) params (MockT IO) (Int -> IO String)
   ) =>
   params ->
-  MockT IO (Int -> IO String)
+  MockT IO (MockResult (Verify.ResolvableParamsOf (Int -> IO String)))
 _findByIdNI p = MockT $ do
   mockInstance <- unMockT $ mock (label "_findByIdNI") p
   ensureVerifiable mockInstance
@@ -259,7 +253,7 @@ _findByIdNI p = MockT $ do
         mockInstance
         NoVerification
     )
-  pure mockInstance
+  pure (MockResult ())
 
 spec :: Spec
 spec = PartialMockCommonSpec.spec deps (program "input.txt" "output.text")
